@@ -1,24 +1,29 @@
 
-"""Top-level package for advertools."""
+"""Digital Marketing productivity and analysis tools."""
 
 __author__ = """Elias Dabbas"""
 __email__ = 'eliasdabbas@gmail.com'
-__version__ = '0.10.6'
+__version__ = '0.13.1'
 
 from advertools.ad_create import ad_create
 from advertools.ad_from_string import ad_from_string
-from advertools.spider import crawl
 from advertools.emoji import *
 from advertools.extract import *
+from advertools.header_spider import crawl_headers
+from advertools.knowledge_graph import knowledge_graph
 from advertools.kw_generate import *
+from advertools.logs import (LOG_FIELDS, LOG_FORMATS, crawllogs_to_df,
+                             logs_to_df)
 from advertools.regex import *
+from advertools.reverse_dns_lookup import reverse_dns_lookup
 from advertools.robotstxt import *
 from advertools.sitemaps import sitemap_to_df
+from advertools.spider import crawl
 from advertools.stopwords import stopwords
 from advertools.url_builders import url_utm_ga
 from advertools.urlytics import url_to_df
 from advertools.word_frequency import word_frequency
 from advertools.word_tokenize import word_tokenize
-from . import twitter
-from . import youtube
+
+from . import twitter, youtube
 from .serp import *
