@@ -3,6 +3,48 @@
 
 Import Search Engine Results Pages (SERPs) for Google and YouTube
 =================================================================
+Analyzing a single SERP is like getting one person to fill out a questionnaire
+and calling it a survey.
+
+Just like surveys, SERPs need to be collected in large-enough numbers that are
+representative of the industry/market you want to understand. This is the main
+feature of the ``serp_`` functions. They allow you to get the SERPs for a list
+of queries, across several dimensions (like country, search type, start
+position, and so on).
+
+There are many parameters that can be used, and you can supply a list for each.
+The function will get the SERPs for the *product* of all those lists. For
+example, let's say you you provide the following arguments to the
+:func:`serp_goog` function:
+
+* `q`: ['serp tools', 'best serp tools', 'serp tool reviews']
+* `gl`: ['us', 'ca', 'uk', 'au', 'nz']
+* `start`: [1, 11, 21]
+
+The function will produce:
+3 (queries) x 5 (countries) x 3 (start positions) = 45 requests
+
+You typically get ten results each, so in this case you would get 450 rows of
+data.
+
+All this is done in with one line of code. The result is a single DataFrame
+with a row for each result, and columns for each attribute (title, snippet,
+etc.), as well as meta data columns, like `queryTime` and the parameters you
+selected (`q`, `gl`, and `start` in this case).
+
+
+Before being able to run queries using :func:`serp_goog`, you will need to set
+up some credentials as follows (you don't need a custom search engine for
+:func:`serp_youtube`):
+
+* `Create a custom search engine <https://cse.google.com/>`_: At first, you might be asked to enter a site to search. Enter any domain, then go to the control panel and remove it. Make sure you enable "Search the entire web" and image search. You will also need to get your search engine ID, which you can find on the control panel page.
+
+* `Enable the custom search API <https://console.cloud.google.com/apis/library/customsearch.googleapis.com?pli=1>`_: The service will allow you to retrieve and display search results from your custom search engine programmatically. You will need to create a project for this first.
+
+* `Create credentials for this project <https://console.developers.google.com/apis/api/customsearch.googleapis.com/credentials>`_: so you can get your key.
+
+* `Enable billing for your project <https://console.cloud.google.com/billing/projects>`_ if you want to run more than 100 queries per day. The first 100 queries are free; then for each additional 1,000 queries, you pay $5.
+
 
 """
 __all__ = ['SERP_GOOG_VALID_VALS', 'YOUTUBE_TOPIC_IDS',
@@ -15,6 +57,7 @@ import logging
 from itertools import product
 
 import pandas as pd
+
 if int(pd.__version__[0]) >= 1:
     from pandas import json_normalize
 else:
@@ -438,7 +481,7 @@ def youtube_video_details(key, vid_ids):
             except KeyError:
                 continue
         temp_df = pd.concat([items_df, detail_df], axis=1)
-        final_df = final_df.append(temp_df, sort=False, ignore_index=True)
+        final_df = pd.concat([final_df, temp_df], sort=False, ignore_index=True)
     return final_df
 
 
@@ -469,7 +512,7 @@ def youtube_channel_details(key, channel_ids):
             except KeyError:
                 continue
         temp_df = pd.concat([items_df, detail_df], axis=1)
-        final_df = final_df.append(temp_df, sort=False, ignore_index=True)
+        final_df = pd.concat([final_df, temp_df], sort=False, ignore_index=True)
     return final_df
 
 
@@ -649,10 +692,12 @@ def serp_goog(q, cx, key, c2coff=None, cr=None,
     >>> serp_goog(q='hotel', gl=['us', 'fr'], cx='YOUR_CX', key='YOUR_KEY')
 
     The below function call will prouce four queries and make four requests:
-    "fligts" in UK
-    "fligts" in Australia
-    "tickets" in UK
-    "tickets" in Australia
+
+    * "fligts" in UK
+    * "fligts" in Australia
+    * "tickets" in UK
+    * "tickets" in Australia
+
     'cr' here refers to 'country restrict', which focuses on content
     originating from the specified country.
 
@@ -714,7 +759,7 @@ def serp_goog(q, cx, key, c2coff=None, cr=None,
             img_df = json_normalize(df['image'])
             img_df.columns = ['image.' + c for c in img_df.columns]
             df = pd.concat([df, img_df], axis=1)
-        result_df = result_df.append(df, sort=False, ignore_index=True)
+        result_df = pd.concat([result_df, df], sort=False, ignore_index=True)
     ordered_cols = (list(set(params_list[i]).difference({'q', 'key', 'cx'})) +
                     specified_cols)
     non_ordered = result_df.columns.difference(set(ordered_cols))
@@ -724,11 +769,11 @@ def serp_goog(q, cx, key, c2coff=None, cr=None,
         for p in final_df['pagemap']:
             try:
                 temp_pagemap_df = json_normalize(p)
-                pagemap_df = pagemap_df.append(temp_pagemap_df, sort=False)
+                pagemap_df = pd.concat([pagemap_df, temp_pagemap_df], sort=False)
             except Exception as e:
                 temp_pagemap_df = pd.DataFrame({'delete_me': None},
                                                 index=range(1))
-                pagemap_df = pagemap_df.append(temp_pagemap_df, sort=False)
+                pagemap_df = pd.concat([pagemap_df, temp_pagemap_df], sort=False)
         pagemap_df = pagemap_df.reset_index(drop=True)
         if 'delete_me' in pagemap_df:
             del pagemap_df['delete_me']
@@ -742,13 +787,13 @@ def serp_goog(q, cx, key, c2coff=None, cr=None,
             for m in pagemap_df['metatags']:
                 try:
                     temp_metatags_df = json_normalize(m)
-                    metatag_df = metatag_df.append(temp_metatags_df,
-                                                   sort=False)
+                    metatag_df = pd.concat([metatag_df, temp_metatags_df],
+                                           sort=False)
                 except Exception as e:
                     temp_metatags_df = pd.DataFrame({'delete_me': None},
                                                     index=range(1))
-                    metatag_df = metatag_df.append(temp_metatags_df,
-                                                   sort=False)
+                    metatag_df = pd.concat([metatag_df, temp_metatags_df],
+                                           sort=False)
             metatag_df = metatag_df.reset_index(drop=True)
             if 'delete_me' in metatag_df:
                 del metatag_df['delete_me']
@@ -1147,8 +1192,8 @@ def serp_youtube(key, q=None, channelId=None, channelType=None, eventType=None,
         del params_list[i]['key']
         temp_df = temp_df.assign(**params_list[i])
         temp_df['nextPageToken'] = resp.json().get('nextPageToken')
-        result_df = result_df.append(temp_df, sort=False,
-                                     ignore_index=True)
+        result_df = pd.concat([result_df, temp_df], sort=False,
+                              ignore_index=True)
 
     result_df['queryTime'] = datetime.datetime.now(tz=datetime.timezone.utc)
     result_df['queryTime'] = pd.to_datetime(result_df['queryTime'])
