@@ -1,15 +1,80 @@
 """
+
 .. _twitter:
 
 Twitter Data API
 ================
+Easily connect to the Twitter API and start your analysis immediately.
+
+Main Features:
+
+1 **Get the results in a DataFrame**: With the exception of three functions
+that return a list of ID's, everything else returns a pandas DataFrame, ready
+to use. This allows you to spend more time analyzing data, and less time
+figuring out the structure of the JSON response object. It's not complicated
+or anything, just takes time.
+
+2 **Manage looping and merging**: there is a limit on how many results you get
+per request (typically in the 100 - 200 range), several requests have to be
+made, and merged together. Not all responses have the same structure, so this
+is also handled. You only have to provide the number of responses you want
+through the ``count`` parameter where applicable (provided you are within
+your app's rate limits).
+
+3 **Unnesting nested objects**: Many response objects contain very rich
+embedded data, which is usually meta data about the response. For example,
+when you request tweets, you get a user object along with that. This is very
+helpful in better understanding who made the tweet, and how
+influential/credible they are.
+
+4 **Documentation**: All available parameters are included in the function
+signatures, to make it easier to explore interactively, as well as
+descriptions of the parameters imported from the Twitter documentation.
+
+Authentication
+--------------
+
+Before starting you will have to create an app through
+`developer.twitter.com <https://developer.twitter.com/>`_, and then you can get
+your authentication keys from your dashboard. Then you can authenticate as
+follows:
+
+.. code-block:: python
+
+   >>> auth_params = {
+   ...     'app_key': 'YOUR_APP_KEY',
+   ...     'app_secret': 'YOUR_APP_SECRET',
+   ...     'oauth_token': 'YOUR_OAUTH_TOKEN',
+   ...     'oauth_token_secret': 'YOUR_OAUTH_TOKEN_SECRET',
+   ... }
+   >>> import advertools as adv
+   >>> adv.twitter.set_auth_params(**auth_params)
+
+Now every request you send will include your ``auth_params`` in it, and if
+valid you will get the respective response, for example:
+
+.. code-block:: python
+
+   >>> python_tweets = adv.twitter.search(q='#python', tweet_mode='extended')
+
+Make sure you always specify ``tweet_mode='extended'`` because otherwise you
+will get tweets that are 140 characters long.
+
+When you have tweets and user data in the DataFrame, the column names would be
+prepended with ``tweet_`` and ``user_`` to make it clear what the data belong
+to.
+
+
+Functions
+---------
 """
 
 import logging
 from functools import wraps
 
-from twython import Twython
 import pandas as pd
+from twython import Twython
+
 if int(pd.__version__[0]) >= 1:
     from pandas import json_normalize
 else:
@@ -208,7 +273,7 @@ def make_dataframe(func):
                     temp_df = pd.concat([resp_df, user_df], axis=1)
                 else:
                     temp_df = resp_df
-            final_df = final_df.append(temp_df, sort=False, ignore_index=True)
+            final_df = pd.concat([final_df, temp_df], sort=False, ignore_index=True)
 
         for col in final_df:
             if 'created_at' in col:
@@ -259,7 +324,7 @@ def get_application_rate_limit_status(consumed_only=True):
     limit_df = pd.DataFrame()
     for resource in ratelimit['resources']:
         temp_df = pd.DataFrame(ratelimit['resources'][resource]).T
-        limit_df = limit_df.append(temp_df, sort=False)
+        limit_df = pd.concat([limit_df, temp_df], sort=False)
     limit_df['reset'] = pd.to_datetime(limit_df['reset'], unit='s')
     limit_df['resource'] = limit_df.index.str.split('/').str[1]
     limit_df.index.name = 'endpoint'
@@ -693,7 +758,7 @@ def get_place_trends(ids, exclude=None):
         trend_df['woeid'] = place_trends[0]['locations'][0]['woeid']
         trend_df['time'] = pd.to_datetime(place_trends[0]['created_at'])
 
-        trends_df = trends_df.append(trend_df, ignore_index=True)
+        trends_df = pd.concat([trends_df, trend_df], ignore_index=True)
 
     trends_df = trends_df.sort_values(['woeid', 'tweet_volume'],
                                       ascending=[True, False])
