@@ -1,3 +1,4 @@
+import numpy as np
 import pandas as pd
 from advertools.urlytics import url_to_df
 
@@ -12,6 +13,11 @@ fragment = 'https://example.com/#fragment'
 fragment_rel = '/#fragment_rel'
 full = 'ftp://example.com:20/cat/sub_cat?one=10&three=30#frag_2'
 
+ordered_q_param_urls = ['https://example.com?a=a&b=b&c=c',
+                        'https://example.com?b=b&c=c',
+                        'https://example.com?c=c',
+                        'https://example.com?a=a&c=c']
+
 
 def test_urltodf_convert_str_tolist():
     result = url_to_df('https://www.example.com')
@@ -20,14 +26,17 @@ def test_urltodf_convert_str_tolist():
 
 def test_path_rel_noslash():
     result = url_to_df(path_rel_noslash)
-    assert result['scheme'][0] == ''
-    assert result['netloc'][0] == ''
+    assert pd.isna(result['scheme'][0])
+    assert pd.isna(result['netloc'][0])
 
 
 def test_abs_and_rel():
     result = url_to_df([domain, path_rel])
     assert 'dir_1' in result
     assert len(result) == 2
+    assert result['scheme'].iloc[-1] is np.nan
+    assert result['query'].isna().all()
+    assert result['fragment'].isna().all()
 
 
 def test_domainpath_fragrel_full():
@@ -38,9 +47,25 @@ def test_domainpath_fragrel_full():
     assert query_set.intersection(result.columns) == query_set
 
 
+def test_no_path_has_no_last_dir():
+    result = url_to_df(domain_query)
+    assert 'last_dir' not in result
+
+
 def test_all():
     result = url_to_df([domain, domain_path, path_rel, domain_query,
                         domain_query_rel, port, fragment, fragment_rel, full])
     assert len(result) == 9
     assert 'port' in result
     assert 'hostname' in result
+    assert 'last_dir' in result
+
+
+def test_query_params_are_ordered_by_fullness():
+    result = url_to_df(ordered_q_param_urls)
+    query_df = result.filter(regex='^query_')
+    sorted_q_params = (query_df
+                       .notna()
+                       .mean()
+                       .sort_values(ascending=False).index)
+    assert (query_df.columns == sorted_q_params).all()
